# -*- coding: utf-8 -*-

import numpy as np
from dateutil.parser import parse as du_parse


class DshipAISExtract(object):
    """
    Class to ingest standard DSHIP/realtime extraction AIS station data.
    """

    def __init__(self, filepath, zero_lonlat_to_nan=True):
        self.filepath = filepath
        self.zero_lonlat_to_nan = zero_lonlat_to_nan
        self.time = None
        self._parse()

    def _parse(self):
        """
        Read time, lat, lon, heading from DSHIP extract
        :return:
        """

        # Read ASCII extract
        self.csv_var_dtypes = dict(
            names=['date', 'time', 'latitude', 'longitude'],
            formats=['U10', 'U8', 'f4', 'f4'])
        self.content = np.loadtxt(self.filepath, dtype=self.csv_var_dtypes)

        # Compute datetime
        self.time = np.ndarray(shape=tuple([self.n_records]), dtype=object)
        for i in np.arange(self.n_records):
            datetime_str = self.content["date"][i].replace("/", "")+"T"+self.content["time"][i]
            self.time[i] = du_parse(datetime_str)

        if self.zero_lonlat_to_nan:
            lon_is_zero = np.abs(self.longitude) <= 1.e-6
            lat_is_zero = np.abs(self.latitude) <= 1.e-6
            lonlat_are_zero = np.where(np.logical_and(lon_is_zero, lat_is_zero))[0]
            for target in ["longitude", "latitude"]:
                self.content[target][lonlat_are_zero] = np.nan

    @property
    def longitude(self):
        return self.content["longitude"]

    @property
    def latitude(self):
        return self.content["latitude"]

    @property
    def n_records(self):
        return self.content.size

    @property
    def time_bounds(self):
        return [self.time[0], self.time[-1]]